#[repr(C)]pub struct VregGetRegulatorParamsResponse {
pub min_uv: u32,
pub step_size_uv: u32,
pub num_steps: u32,
}Fields
min_uv: u32step_size_uv: u32num_steps: u32Trait Implementations
Sourceimpl Clone for VregGetRegulatorParamsResponse
impl Clone for VregGetRegulatorParamsResponse
Sourcefn clone(&self) -> VregGetRegulatorParamsResponse
fn clone(&self) -> VregGetRegulatorParamsResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<D> Decode<VregGetRegulatorParamsResponse, D> for VregGetRegulatorParamsResponsewhere
D: ResourceDialect,
impl<D> Decode<VregGetRegulatorParamsResponse, D> for VregGetRegulatorParamsResponsewhere
D: ResourceDialect,
Sourcefn new_empty() -> VregGetRegulatorParamsResponse
fn new_empty() -> VregGetRegulatorParamsResponse
Creates a valid instance of
Self. The specific value does not matter,
since it will be overwritten by decode.Sourceimpl<D> Encode<VregGetRegulatorParamsResponse, D> for &VregGetRegulatorParamsResponsewhere
D: ResourceDialect,
impl<D> Encode<VregGetRegulatorParamsResponse, D> for &VregGetRegulatorParamsResponsewhere
D: ResourceDialect,
Sourceimpl Ord for VregGetRegulatorParamsResponse
impl Ord for VregGetRegulatorParamsResponse
Sourcefn cmp(&self, other: &VregGetRegulatorParamsResponse) -> Ordering
fn cmp(&self, other: &VregGetRegulatorParamsResponse) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for VregGetRegulatorParamsResponse
impl PartialEq for VregGetRegulatorParamsResponse
Sourcefn eq(&self, other: &VregGetRegulatorParamsResponse) -> bool
fn eq(&self, other: &VregGetRegulatorParamsResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for VregGetRegulatorParamsResponse
impl PartialOrd for VregGetRegulatorParamsResponse
Sourceimpl TypeMarker for VregGetRegulatorParamsResponse
impl TypeMarker for VregGetRegulatorParamsResponse
Sourcetype Owned = VregGetRegulatorParamsResponse
type Owned = VregGetRegulatorParamsResponse
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for VregGetRegulatorParamsResponse
impl ValueTypeMarker for VregGetRegulatorParamsResponse
Sourcetype Borrowed<'a> = &'a VregGetRegulatorParamsResponse
type Borrowed<'a> = &'a VregGetRegulatorParamsResponse
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreSourcefn borrow(
value: &<VregGetRegulatorParamsResponse as TypeMarker>::Owned,
) -> <VregGetRegulatorParamsResponse as ValueTypeMarker>::Borrowed<'_>
fn borrow( value: &<VregGetRegulatorParamsResponse as TypeMarker>::Owned, ) -> <VregGetRegulatorParamsResponse as ValueTypeMarker>::Borrowed<'_>
Cheaply converts from
&Self::Owned to Self::Borrowed.impl Copy for VregGetRegulatorParamsResponse
impl Eq for VregGetRegulatorParamsResponse
impl Persistable for VregGetRegulatorParamsResponse
impl StructuralPartialEq for VregGetRegulatorParamsResponse