pub struct VregMarker;Trait Implementations
Sourceimpl Clone for VregMarker
impl Clone for VregMarker
Sourcefn clone(&self) -> VregMarker
fn clone(&self) -> VregMarker
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VregMarker
impl Debug for VregMarker
Sourceimpl DiscoverableProtocolMarker for VregMarker
impl DiscoverableProtocolMarker for VregMarker
Sourceconst PROTOCOL_NAME: &'static str = <Self as ProtocolMarker>::DEBUG_NAME
const PROTOCOL_NAME: &'static str = <Self as ProtocolMarker>::DEBUG_NAME
The name of the protocol (to be used for service lookup and discovery).
Sourceimpl Hash for VregMarker
impl Hash for VregMarker
Sourceimpl Ord for VregMarker
impl Ord for VregMarker
Sourcefn cmp(&self, other: &VregMarker) -> Ordering
fn cmp(&self, other: &VregMarker) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for VregMarker
impl PartialEq for VregMarker
Sourceimpl PartialOrd for VregMarker
impl PartialOrd for VregMarker
Sourceimpl ProtocolMarker for VregMarker
impl ProtocolMarker for VregMarker
Sourceconst DEBUG_NAME: &'static str = "fuchsia.hardware.vreg.Vreg"
const DEBUG_NAME: &'static str = "fuchsia.hardware.vreg.Vreg"
The name of the protocol suitable for debug purposes. Read more
Sourcetype Proxy = VregProxy
type Proxy = VregProxy
The type of the structure against which FIDL requests are made.
Queries made against the proxy are sent to the paired
ServerEnd.Sourcetype RequestStream = VregRequestStream
type RequestStream = VregRequestStream
The type of the stream of requests coming into a server.
Sourcetype SynchronousProxy = VregSynchronousProxy
type SynchronousProxy = VregSynchronousProxy
The type of the structure against which thread-blocking FIDL requests are made.
Queries made against the proxy are sent to the paired
ServerEnd.impl Copy for VregMarker
impl Eq for VregMarker
impl StructuralPartialEq for VregMarker